@@ -1,9 +1,9 @@
 # Verilog::SigParser.pm -- Verilog signal parsing
-# $Revision: #52 $$Date: 2004/11/18 $$Author: ws150726 $
+# $Revision: 1.55 $$Date: 2005-01-24 10:18:02 -0500 (Mon, 24 Jan 2005) $$Author: wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
-# Copyright 2000-2004 by Wilson Snyder.  This program is free software;
+# Copyright 2000-2005 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
 # 
@@ -46,10 +46,14 @@ appropriate:
 
 =over 4
 
-=item $self->module ( $keyword, $name, $symbol_list, $in_celldefine )
+=item $self->module ( $keyword, $name, ignored, $in_celldefine )
 
 This method is called when a module is defined.
 
+=item $self->port ( $name )
+
+This method is called when a module port is defined.
+
 =item $self->task ( $keyword, $name )
 
 This method is called when a module is defined.
@@ -96,7 +100,7 @@ that aren't covered.
 The latest version is available from CPAN and from
 L<http://www.veripool.com/verilog-perl.html>.
 
-Copyright 2000-2004 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2005 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License or the Perl Artistic License.
 
@@ -132,7 +136,7 @@ use Verilog::Parser;
 # Other configurable settings.
 $Debug = 0;		# for debugging
 
-$VERSION = '2.303';
+$VERSION = '2.310';
 
 #######################################################################
 
@@ -161,7 +165,7 @@ sub module {
     my $self = shift;
     my $keyword = shift;
     my $name = shift;
-    my $symbol_list = shift;
+    shift;  # Ignored
     my $in_celldefine = shift;
 }
 
@@ -198,6 +202,11 @@ sub pin {
     my $number = shift;
 }
 
+sub port {
+    my $self = shift;
+    my $name = shift;
+}
+
 sub attribute {
     my $self = shift;
     my $keyword = shift;
@@ -239,6 +248,7 @@ sub reset {
     $self->{in_celldefine} = 0;
     $self->{in_vector} = 0;
     $self->{in_param_assign} = 0;
+    $self->{in_ports} = 0;
     $self->{possibly_in_param_assign} = 0;
     $self->{pin_name} = undef;
 
@@ -312,11 +322,15 @@ sub symbol {
     my $token = shift;	# What token was parsed
 
     if ($self->{in_preproc_line} != $self->line()) {
-	if ($self->{in_vector} == 1) {
+	if ($self->{in_vector}) {
 	    $self->{last_vectors} = $self->{last_vectors} . $token;
-	} elsif ($self->{in_param_assign} == 1) {
+	} elsif ($self->{in_param_assign}) {
 	    $self->{last_param} = $self->{last_param} . $token;
 	} else {
+	    if ($self->{in_ports}) {
+		print " Gotaport $token\n"    if $Debug;
+		$self->port ($token);
+	    }
 	    push @{$self->{last_symbols}}, $token;
 	}
     } else {
@@ -362,7 +376,7 @@ sub operator {
 	    $self->{in_vector} = 0;
 	    $self->{last_vectors} = $self->{last_vectors} . $token;
 	}
-	elsif ($self->{in_vector} == 1) {
+	elsif ($self->{in_vector}) {
 	    $self->{last_vectors} = $self->{last_vectors} . $token;
 	}
 	elsif ($self->{in_param_assign}) {
@@ -389,6 +403,16 @@ sub operator {
 	    $self->{is_inst_ok} = 0;
 	    $self->{is_pin_ok} = 1;
 	}
+	elsif (($token eq "(" || $token eq ";")
+	       && ($lkw eq "module" || $lkw eq "primitive")) {
+	    my $mod = shift @{$self->{last_symbols}};
+	    $self->{last_module} = $mod;
+	    print "Gota$lkw $mod\n"    if ($Debug);
+	    $self->module ($lkw, $mod, undef, $self->{in_celldefine});
+	    $self->{last_keyword} = ""; $lkw="";
+	    $self->{in_ports} = 1;
+	    # Fallthru, more ; prep for next command is below
+	}
 	elsif ($token eq "," || $token eq ";") {
 	    if ($self->{is_pin_ok}
 		&& (defined $self->{last_symbols}[0]
@@ -402,6 +426,7 @@ sub operator {
 		my $pin_name = $self->{pin_name};
 		$namedports = 1 if defined $pin_name;
 		$pin_name ||= "pin" . $self->{is_pin_ok};
+		print "Gotapin $pin_name\n"    if ($Debug);
 		$self->pin ($pin_name,
 			    $sym . $vec,
 			    $self->{is_pin_ok},
@@ -418,19 +443,13 @@ sub operator {
 		$self->{is_inst_ok} = 1;
 	    }
 
-	    if ($token eq ";" || $token eq "=") {
+	    if ($token eq ";" || $token eq "="
+		|| ($token eq "," && $self->{in_ports})) {
 		if ($lkw eq "task") {
 		    my $mod = $self->{last_symbols}[0];
 		    $self->{last_task} = $mod;
 		    print "Gota$lkw $mod\n"    if ($Debug);
 		    $self->task ($lkw, $mod);
-		} elsif ($lkw eq "module"
-			 || $lkw eq "primitive") {
-		    my $mod = shift @{$self->{last_symbols}};
-		    $self->{last_module} = $mod;
-		    print "Gota$lkw $mod\n"    if ($Debug);
-		    $self->module ($lkw, $mod, $self->{last_symbols},
-				   $self->{in_celldefine});
 		} elsif ($lkw eq "function") {
 		    my $mod = $self->{last_symbols}[0];
 		    $self->{last_function} = $mod;
@@ -459,7 +478,7 @@ sub operator {
 				$vec = $self->{last_vectors};
 			    }
 			}
-			#print "Gota$lkw $sig $vec $mem\n"    if ($Debug);
+			print "Gota$lkw $sig $vec $mem\n"    if ($Debug);
 			$self->signal_decl ($lkw, $sig, $vec, $mem);
 		    }
 		}
@@ -471,12 +490,15 @@ sub operator {
 		    $self->{is_inst_ok} = 1;
 		    $self->{is_signal_ok} = 1;
 		    $self->{is_pin_ok} = 0;
+		    $self->{in_ports} = 0;
 		    $self->{got_preproc} = 0;
 		}
 		elsif ( $token eq "=") {
 		    $self->{is_signal_ok} = 0;
 		    $self->{is_inst_ok} = 0;
 		}
+		elsif ( $token eq ",") {
+		}
 		else { die "programming error\n" };
 	    }
 	}
